@@ -2,7 +2,22 @@
 /**
  * タグ管理のコントローラ
  *
- * LICENSE: ライセンスに関する情報
+ * Copyright (c) 2010-2011 SetucoCMS Project.(http://sourceforge.jp/projects/setucocms)
+ * All Rights Reserved.
+ * 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
  * @category   Setuco
  * @package    Admin
@@ -165,20 +180,17 @@ class Admin_TagController extends Setuco_Controller_Action_AdminAbstract
         $stringLength->setEncoding("UTF-8");
         $validators[] = array($stringLength, true);
 
-        $noRecordExistsOption = array(
-                'table' => 'tag',
-                'field' => 'name'
-        );
-
-        if ($isEditing) {
-            $noRecordExistsOption['exclude'] = array('field' => 'id', 'value' => $this->_getParam('id'));
+        if ($isEditing != true) {
+            $noRecordExists = new Zend_Validate_Db_NoRecordExists(
+                array(
+                    'table' => 'tag',
+                    'field' => 'name'
+                )
+            );
+            $noRecordExists->setMessage('「%value%」は既に登録されています。');
+            $validators[] = array($noRecordExists, true);
         }
 
-        $noRecordExists = new Zend_Validate_Db_NoRecordExists($noRecordExistsOption);
-        $noRecordExists->setMessage('「%value%」は既に登録されています。');
-        $validators[] = array($noRecordExists, true);
-
-
         return $validators;
     }
 
